Watson-Common
=============

Useful common utility functions and classes for working with lists,
dictionaries, importlib and xml.

For full documentation please see `Read The
Docs <http://watson-common.readthedocs.org/>`__.

Build Status
^^^^^^^^^^^^

|Build Status| |Coverage Status| |Version| |Downloads| |Licence|

Installation
------------

``pip install watson-common``

Requirements
------------

.. |Build Status| image:: https://api.travis-ci.org/watsonpy/watson-common.png?branch=master
   :target: https://travis-ci.org/watsonpy/watson-common
.. |Coverage Status| image:: https://coveralls.io/repos/watsonpy/watson-common/badge.png
   :target: https://coveralls.io/r/watsonpy/watson-common
.. |Version| image:: https://pypip.in/v/watson-common/badge.png
   :target: https://pypi.python.org/pypi/watson-common/
.. |Downloads| image:: https://pypip.in/d/watson-common/badge.png
   :target: https://pypi.python.org/pypi/watson-common/
.. |Licence| image:: https://pypip.in/license/watson-common/badge.png
   :target: https://pypi.python.org/pypi/watson-common/
